==> klayout-0.15.tar.gz: klayout-0.15/src/tlAssert.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_tlAssert
#define HDR_tlAssert

#include <tlException.h>
#include <tlLog.h>

namespace tl
{

/**
 *  @brief A special "internal" exception class
 */

struct InternalException
  : public Exception
{
  InternalException (const char *file, int line, const char *cond)
    : Exception (tl::translate ("Internal error: %s:%d %s was not true").c_str (), file, line, cond)
  { }
};

/** 
 *  @brief The corresponding assert macro
 */

void assertion_failed (const char *filename, unsigned int line, const char *condition);

//  the throw int(0) instruction will tell the compiler that the assertion will not return
#define tl_assert(COND) if (!(COND)) { tl::assertion_failed (__FILE__, __LINE__, #COND); throw int(0); }

} // namespace tl

#endif

==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/tlAssert.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_tlAssert
#define HDR_tlAssert

#include "config.h"

#include "tlException.h"
#include "tlLog.h"

namespace tl
{

/**
 *  @brief A special "internal" exception class
 */

struct InternalException
  : public Exception
{
  InternalException (const char *file, int line, const char *cond)
    : Exception (tl::translate ("Internal error: %s:%d %s was not true").c_str (), file, line, cond)
  { }
};

/** 
 *  @brief The corresponding assert macro
 */

KLAYOUT_DLL void assertion_failed (const char *filename, unsigned int line, const char *condition);

//  the throw int(0) instruction will tell the compiler that the assertion will not return
#define tl_assert(COND) if (!(COND)) { tl::assertion_failed (__FILE__, __LINE__, #COND); throw int(0); }

} // namespace tl

#endif
